tally
=====

A Django application (and daemon) for collecting, storing, and aggregating metrics with configurable resolution and retention periods.

Documentation can be found at http://tally.readthedocs.org/en/latest/
